<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Може и без веб прегледача!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Верзија %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Лиценцирано на: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 је слободан софтвер, али његов развој одузма драгоцено време.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Молимо да &lt;a href=&apos;%1&apos;&gt;донацијама&lt;/a&gt; подржите развој програма %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Преведите %1 на ваш матерњи језик помоћу %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Иконицу дизајниро %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Под &lt;a href=&apos;%1&apos;&gt;Гнуовом Општом Јавном Лиценцом</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О програму</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Унесите детаље ваше лиценце</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Е-пошта:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Кôд:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Молимо да купите %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Показна верзија је истекла.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Пуна верзија Вам дозвољава да гледате видео снимке без прекидања.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Без лиценце програм ће истећи за %1 дан(а).</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Куповином пуне верзије ћете уједно и подржати мој рад на програму %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Користи показну верзију</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Унесите лиценцу</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Купите лиценцу</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>За %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Сви видеи</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Непрегледани снимци</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>имену</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Задње ажурирано</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Задње додато</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Задње гледано</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Највише гледано</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Поређај по</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Означи све као прегледано</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Прикажи ажурирано</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Немате претплате. Користи звезду да се претплатиш.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Сви видеи</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Непрегледани снимци</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Означи као погледано</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Ун-претплати се</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Нема ажурираних субскрипција тренутно</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Сада</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 прегледа</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>бајтова</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>b/s</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунди</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>минута</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 преостаје</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 преузето у %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Преузимање завршено</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Промените локацију...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Изаберите локацију преузимања</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Локација преузимања је промењена.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Тренутна преузимања ће се наставити са претходне локације.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Преузимам у: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Преузимања</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Извршни фајл је уништен</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 неће да се покрене. Пробај ре-инсталирати</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Одустани</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Ре-инсталирај</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Пусти</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Паузирај</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Пусти или паузирај</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Заустави</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Заустави пуштање након тренутне стазе</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Следећа стаза</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Претходна стаза</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Појачај</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Утишај</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Искључи тон</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Премотај унапред</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Премотај уназад</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Претрага</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Претражи снимке и канале речју</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Претражи</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Претражи снимке по категорији</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Претплате</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Претплате канала</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Раскомотите се</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Прозор</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Минимизуј</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Заустави</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Зауставља пуштање и враћа се на приказ претраге</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>П&amp;ретходни</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Иде на претходну нумеру</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Прес&amp;кочи</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Пушта следећи снимак</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Пусти</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Настави пуштање</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Целоекрански приказ</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Прелази у целоекрански приказ</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Компактан режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Скрива плејлисту и траке алатки</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Отвори страницу на &amp;Јутјубу</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Паузира пуштање и одлази на страницу на Јутјубу</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Копирај &amp;везу са Јутјуба</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Копира Јутјуб везу тренутног видеау у клипборд</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Копирај &amp;УРЛ видео тока</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Копирај УРЛ тренутног видео тока у клипборд</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Нађи &amp;делове видеа</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Нађи остале делове видеа, можда и у исправном редоследу</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Уклања изабране снимке из плејлисте</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Помери на&amp;више</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Помера изабране снимке навише у плејлисти</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Помери на&amp;ниже</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Помера изабаране снимке наниже у плејлити</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Очисти недавне претраге</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Уклања историјат претраге. Не може се опозвати.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Напусти</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ћао</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Веб сајт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 на вебу</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Донирајте</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Молимо да подржите даљи развој програма %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О програму</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Подаци о програму %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Претрага</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Искључи тон</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Ручно покретање пуштања</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Пуштање видеа се покреће ручно</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Преузимања</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Приказује детаље о преузетим видео снимцима</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Преузми</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Преузима тренутни видео</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Узми &amp;Слику</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Претплати се на Канал</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Дели тренутни видео путем %1 </translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Е-пошта</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Е-пошта</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Флутај на врху</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Зау&amp;стави након овог видеа</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>Пријави &amp;грешку...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Преуреди претрагу...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Још</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Сродни снимци</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Гледај снимке сродне тренутном</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Отвори у &amp;Претраживачу...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Обожавате %1? Оцените!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Купите %1....</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Програм</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Пуштање</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Плејлиста</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Видео</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Дељење</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Приказ</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помоћ</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Притисните %1 да би појачали, односно %2 да би утишали тон</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Одабери локацију тога</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Отварам %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Желите ли а напустите %1 током активног преузимања?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Уколико затворите %1 сада ово преузимање ћњ бити отказано.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Затвори и откажи преузимање</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Сачекајте да се преузимање заврши</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Грешка:%1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Паузирај</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Паузира пуштање</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Учитавање...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Напусти &amp;цео екран</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Преостало време: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Јачина тона %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Тон је искључен</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Тон  је поново укључен</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Максимална дефиниција видеа је постављена на  %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Ваша приватност је сада осигурана</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Преузимања су завршена</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>Доступан је %1 верзије %2.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Подести ме касније</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Ажурирај</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Сад можете налепити везу са Јутјуба у други програм</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Сад можете УРЛ видео тока налепити у други програм</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Веза је исправна само одређено време.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>преузимам %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>од</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>део</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>епизода</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Послато са %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Ун-претплати се од %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Претплати се на %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Ун-претплаћен од %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Претплаћен на %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Ново издање %1 је доступно!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 је доступан! Код вас је %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Желите ли да га преузмете одмах?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Прескочи</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Касније</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Инсталирај</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Налепи</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 од %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Припремам</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Неуспех</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Завршено</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Заустављено</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Заустави преузимање</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Прикажи у %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Отвори недавни фолдер</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Рестартуј преузимање</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Прикажи још %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Нема снимака</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Нема других снимака</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Поређај по</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Потребно</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Датум</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Види број</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Оцењивање</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Било кад</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Данас</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Дана</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Дана</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Трајање</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Кратко</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Средње</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Дуго</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Мање од 4 минуте</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Између 4 и 20 минута</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Дуже од 20 минута</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Квалитет</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Високо Дефинисано</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p или више</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Довршено</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Довршено</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Претрага</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Добродошли у &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>да би започели преглед видео снимака.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>кључну реч</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>унесите</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Недавни кључне речи</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Недавни канали</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Преузмите пуну верзију</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Напред до %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Назад до %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Преуреди претрагу</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Да ли сте мислили: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Промените локацију...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Слике сачуване у %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Локација слика је промењена</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Најпопуларније</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Преузимам надоградњу... </translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Алжир</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Аргентина</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Аустралија</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Белгија</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Бразил</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Канада</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Чиле</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Колумбија</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Чешка Република</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Египт</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Француска</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Немачка</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Гана</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Грчка</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Хонг Конг</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Мађарска</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Индија</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Индонезија</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ирска</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Израел</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Италија</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Јапан</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Јордан</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Кенија</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Малезија</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Мексико</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Мароко</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Холандија</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Нови Зеланд</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Нигерија</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Перу</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Филипини</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Пољска</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Русија</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Саудијска Арабија</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Сингапур</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Северна Африка</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Северна Кореја</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Шпанија</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Шведска</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Тајван</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Тунис</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Турска</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Уганда</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Уједињени Арапски Епирати</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Уједињено Краљевство</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Јемен</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Широм света</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>не могу да добавим видео ток за %1</translation>
    </message>
</context>
</TS>